import { TrieRoot } from './TrieNode';
import { CompoundWordsMethod } from './walker';
export declare type Cost = number;
export declare type MaxCost = Cost;
export interface SuggestionResult {
    word: string;
    cost: Cost;
}
/**
 * Ask for the next result.
 * maxCost - sets the max cost for following suggestions
 * This is used to limit which suggestions are emitted.
 * If the iterator.next() returns `undefined`, it is to request a value for maxCost.
 */
export declare type SuggestionIterator = Generator<SuggestionResult, undefined, MaxCost | undefined>;
export declare function suggest(root: TrieRoot | TrieRoot[], word: string, numSuggestions?: number, compoundMethod?: CompoundWordsMethod, numChanges?: number, ignoreCase?: boolean): SuggestionResult[];
export declare function genSuggestions(root: TrieRoot | TrieRoot[], word: string, compoundMethod?: CompoundWordsMethod): SuggestionIterator;
export declare function genCompoundableSuggestions(root: TrieRoot, word: string, compoundMethod: CompoundWordsMethod): SuggestionIterator;
export declare function compSuggestionResults(a: SuggestionResult, b: SuggestionResult): number;
export interface SuggestionCollector {
    collect: (src: SuggestionIterator) => void;
    add: (suggestion: SuggestionResult) => SuggestionCollector;
    readonly suggestions: SuggestionResult[];
    readonly maxCost: number;
    readonly word: string;
    readonly maxNumSuggestions: number;
    readonly includesTies: boolean;
    readonly ignoreCase?: boolean;
}
export interface SuggestionCollectorOptions {
    /**
     * number of best matching suggestions.
     */
    numSuggestions: number;
    /**
     * An optional filter function that can be used to limit remove unwanted suggestions.
     * I.E. to remove forbidden terms.
     */
    filter?: (word: string, cost: number) => boolean;
    /**
     * The number of letters that can be changed when looking for a match
     */
    changeLimit: number | undefined;
    /**
     * Include suggestions with tied cost even if the number is greater than `numSuggestions`.
     */
    includeTies?: boolean;
    /**
     * specify if case / accents should be ignored when looking for suggestions.
     */
    ignoreCase: boolean | undefined;
}
export declare function suggestionCollector(wordToMatch: string, options: SuggestionCollectorOptions): SuggestionCollector;
